Index: trunk/psModules/src/detrend/pmFringeStats.h
===================================================================
--- trunk/psModules/src/detrend/pmFringeStats.h	(revision 7828)
+++ trunk/psModules/src/detrend/pmFringeStats.h	(revision 7875)
@@ -5,6 +5,6 @@
  *  @author Eugene Magnier, IfA
  *
- *  @version $Revision: 1.6 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-07-06 03:29:28 $
+ *  @version $Revision: 1.7 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-07-12 04:44:01 $
  *
  *  Copyright 2004 IfA, University of Hawaii
@@ -45,6 +45,21 @@
 // Generate the fringe points
 bool pmFringeRegionsCreatePoints(pmFringeRegions *fringe, // Fringe regions
-                                 const psImage *image // Image for the regions (defines the size)
+                                 const psImage *image, // Image for the regions (defines the size)
+                                 psRandom *random // Random number generator
                                 );
+
+// Write the regions to a FITS file
+bool pmFringeRegionsWriteFits(psFits *fits, // Output FITS file
+                              psMetadata *header, // Header to write, or NULL
+                              const pmFringeRegions *regions, // Regions to write
+                              const char *extname // Extension name, or NULL
+                             );
+
+// Read the regions from a FITS file
+pmFringeRegions *pmFringeRegionsReadFits(psMetadata *header, // Header to read, or NULL
+        const psFits *fits, // Input FITS file
+        const char *extname // Extension name, or NULL
+                                        );
+
 
 
@@ -84,4 +99,5 @@
 // Write the fringe stats for an image to a FITS table
 bool pmFringeStatsWriteFits(psFits *fits, // FITS file to which to write
+                            psMetadata *header, // Header to write, or NULL
                             const pmFringeStats *fringe, // Fringe statistics to be written
                             const char *extname // Extension name for table
@@ -89,6 +105,8 @@
 
 // Read the fringe stats for an image from a FITS table
-pmFringeStats *pmFringeStatsReadFits(const psFits *fits, // FITS file from which to read
-                                     const char *extname // Extension name to read
+pmFringeStats *pmFringeStatsReadFits(psMetadata *header, // Header to read, or NULL
+                                     const psFits *fits, // FITS file from which to read
+                                     const char *extname, // Extension name to read
+                                     pmFringeRegions *regions // Corresponding regions for fringe measurements
                                     );
 
